==> haskell-persistent-2.2.4.1-1-armv7h.pkg.tar.xz: usr/share/haskell/haskell-persistent/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: persistent
version: 2.2.4.1
id: persistent-2.2.4.1-2b50a3e9b6124bb06f6361c04fb03b63
key: persi_K7wUbvhAHlM65PMzIaAotO
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
stability: Stable
homepage: http://www.yesodweb.com/book/persistent
synopsis: Type-safe, multi-backend data serialization.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/persistent>.
category: Database, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
exposed-modules:
    Database.Persist Database.Persist.Quasi Database.Persist.Types
    Database.Persist.Class Database.Persist.Sql
    Database.Persist.Sql.Util
hidden-modules: Database.Persist.Types.Base
                Database.Persist.Class.DeleteCascade
                Database.Persist.Class.PersistEntity
                Database.Persist.Class.PersistQuery
                Database.Persist.Class.PersistUnique
                Database.Persist.Class.PersistConfig
                Database.Persist.Class.PersistField
                Database.Persist.Class.PersistStore Database.Persist.Sql.Migration
                Database.Persist.Sql.Internal Database.Persist.Sql.Types
                Database.Persist.Sql.Raw Database.Persist.Sql.Run
                Database.Persist.Sql.Class Database.Persist.Sql.Orphan.PersistQuery
                Database.Persist.Sql.Orphan.PersistStore
                Database.Persist.Sql.Orphan.PersistUnique
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/persistent-2.2.4.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/persistent-2.2.4.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/persistent-2.2.4.1
hs-libraries: HSpersistent-2.2.4.1-K7wUbvhAHlM65PMzIaAotO
depends:
    aeson-0.11.1.0-01f93b6d659087121e16b9df8deda57c
    attoparsec-0.13.0.1-c82a92403ed30683a5cb6228370c626c
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    base64-bytestring-1.0.0.1-7819850819049320f81b6417431cc8a5
    blaze-html-0.8.1.1-59ea4b5f01886f370857b4d16361c2fc
    blaze-markup-0.7.0.3-4e4a97653c712eed9984271000636729
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    conduit-1.2.6.3-0e2837c15036cd2e0c379e7f893dd487
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    exceptions-0.8.2.1-8c1fe53cd5846ab1f6d4c58870c4f8d9
    fast-logger-2.4.1-72875ca91290e61690089a3e7f5d8466
    http-api-data-0.2.2-107631c0bae2e2a6211651e9a27c130c
    lifted-base-0.2.3.6-26b5b3c50c56a653ba3c5b8bce492107
    monad-control-1.0.0.5-237b0aabd7893e5e3f4b9224e05c849c
    monad-logger-0.3.18-cd8d51c949646894888975572eea97f1
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    old-locale-1.0.0.7-5aedb410aa2e5fddd3c57e9b4de1f46a
    path-pieces-0.2.1-c4c6ea4593a7da7123f92fac6c85ebd3
    resource-pool-0.2.3.2-43a43754061092f307f80bb6d2ee434f
    resourcet-1.1.7.3-3e7ca03abacc332d28328c69bbd74cd4
    scientific-0.3.4.5-648b7dc78cf09ce28c222dfd7438d54f
    silently-1.2.5-7f926db5f44f7696c1a8c4ab976d4845
    tagged-0.8.3-aa128de4449752177a05765fb0ce3959
    template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
    time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    transformers-base-0.4.4-b65bc998c24abf50fea29d4891da9e32
    unordered-containers-0.2.7.0-03f1d2fb96e30aca19bb1467e9476c22
    vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
haddock-interfaces: /usr/share/doc/haskell-persistent/html/persistent.haddock
haddock-html: /usr/share/doc/haskell-persistent/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-persistent-2.2.4.1-3-armv7h.pkg.tar.xz: usr/share/haskell/haskell-persistent/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: persistent
version: 2.2.4.1
id: persistent-2.2.4.1-550ce3a441e5dfee4f5236d6597d598b
key: persi_1DaRqvZLLmTJoyQdIUKCZL
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
stability: Stable
homepage: http://www.yesodweb.com/book/persistent
synopsis: Type-safe, multi-backend data serialization.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/persistent>.
category: Database, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
exposed-modules:
    Database.Persist Database.Persist.Quasi Database.Persist.Types
    Database.Persist.Class Database.Persist.Sql
    Database.Persist.Sql.Util
hidden-modules: Database.Persist.Types.Base
                Database.Persist.Class.DeleteCascade
                Database.Persist.Class.PersistEntity
                Database.Persist.Class.PersistQuery
                Database.Persist.Class.PersistUnique
                Database.Persist.Class.PersistConfig
                Database.Persist.Class.PersistField
                Database.Persist.Class.PersistStore Database.Persist.Sql.Migration
                Database.Persist.Sql.Internal Database.Persist.Sql.Types
                Database.Persist.Sql.Raw Database.Persist.Sql.Run
                Database.Persist.Sql.Class Database.Persist.Sql.Orphan.PersistQuery
                Database.Persist.Sql.Orphan.PersistStore
                Database.Persist.Sql.Orphan.PersistUnique
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/persistent-2.2.4.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/persistent-2.2.4.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/persistent-2.2.4.1
hs-libraries: HSpersistent-2.2.4.1-1DaRqvZLLmTJoyQdIUKCZL
depends:
    aeson-0.11.1.1-0413068b3d94ca1008e286bfe7fa084f
    attoparsec-0.13.0.1-5ea5fcb358e0d896b98f3d37ebae8a45
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    base64-bytestring-1.0.0.1-7819850819049320f81b6417431cc8a5
    blaze-html-0.8.1.1-59ea4b5f01886f370857b4d16361c2fc
    blaze-markup-0.7.0.3-4e4a97653c712eed9984271000636729
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    conduit-1.2.6.4-0dfd87f475e845002478c37d3a30df1e
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    exceptions-0.8.2.1-8c1fe53cd5846ab1f6d4c58870c4f8d9
    fast-logger-2.4.1-72875ca91290e61690089a3e7f5d8466
    http-api-data-0.2.2-107631c0bae2e2a6211651e9a27c130c
    lifted-base-0.2.3.6-26b5b3c50c56a653ba3c5b8bce492107
    monad-control-1.0.0.5-237b0aabd7893e5e3f4b9224e05c849c
    monad-logger-0.3.18-7704b739a8ba950a4b62906c3ab56228
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    old-locale-1.0.0.7-5aedb410aa2e5fddd3c57e9b4de1f46a
    path-pieces-0.2.1-c4c6ea4593a7da7123f92fac6c85ebd3
    resource-pool-0.2.3.2-43a43754061092f307f80bb6d2ee434f
    resourcet-1.1.7.3-3e7ca03abacc332d28328c69bbd74cd4
    scientific-0.3.4.6-460bb668ffbf15e21b1a22bd826e372c
    silently-1.2.5-7f926db5f44f7696c1a8c4ab976d4845
    tagged-0.8.3-aa128de4449752177a05765fb0ce3959
    template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
    time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    transformers-base-0.4.4-b65bc998c24abf50fea29d4891da9e32
    unordered-containers-0.2.7.0-03f1d2fb96e30aca19bb1467e9476c22
    vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
haddock-interfaces: /usr/share/doc/haskell-persistent/html/persistent.haddock
haddock-html: /usr/share/doc/haskell-persistent/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
